@@ -28,12 +28,12 @@ def load_dataset(sc, read_all, input_dest='', header=True):
     module_name = data_storage.split('-')[0].lower()
 
     class_ = get_class(module_name)
-    instance = class_(args)
+    instance = class_(args, sc)
 
-    return instance.load_dataset(sc, read_all, input_dest, header)
+    return instance.load_dataset(read_all, input_dest, header)
 
 
-def save_dataset(df, output_dest=''):
+def save_dataset(sc, df, output_dest=''):
     # df -> Spark dataframe to store
     # output_dest -> destinaion output, if not specified it takes 'output-dataset' destinaion from 'args'
 
@@ -42,7 +42,7 @@ def save_dataset(df, output_dest=''):
     module_name = data_storage.split('-')[0].lower()
 
     class_ = get_class(module_name)
-    instance = class_(args)
+    instance = class_(args, sc)
 
     return instance.save_dataset(df, output_dest)
 
