@@ -62,8 +62,6 @@ def spark_initializer(app_name, args, additional_config=[]):
             .enableHiveSupport() \
             .getOrCreate()
 
-        # Hive session
-        hive = HiveContext(spark)
     else:
 
         if len(additional_config) is 0:
