@@ -15,7 +15,7 @@ if __name__ == '__main__':
             args[p[0].replace("--", "", 1)] = p[1]
 
     # Spark initializer + create dataset
-    spark = spark_initializer("PySpark-Utilities-Test", args)
+    spark = spark_initializer("PySpark-Utilities-Test", args, additional_config=[('spark.jars.packages', 'io.prestosql:presto-jdbc:350')])
 
     test = [("Finance",10),
             ("Marketing",20),
